@@ -13,7 +13,7 @@ from oasys.widgets import widget
 from oasys.util.oasys_util import TriggerIn, TriggerOut, EmittingStream
 
 from orangecontrib.wofry.util.wofry_objects import WofryData
-from orangecontrib.esrf.shadow.util.python_script import PythonConsole
+from orangecontrib.esrf.shadow.util.python_script import PythonConsole # TODO: this needs that OASYS1-ESRF-Extensions
 
 
 # from oasys.widgets import gui as oasysgui
@@ -464,11 +464,10 @@ def to_python_code(self, # self is beamline
     elif graph_file_flag == 2:
         dump_file = "%s.pdf" % root_file_name
 
-    full_text_code += "\n\n" + indent + 'tally.plot_intensity_accumulated(show=%d,filename="%s",coordinates_factor=1e6)' % (show_graph_flag, dump_file)
-
+    full_text_code += "\n\n" + indent + 'tally.plot_intensity_accumulated(show=%d,filename="%s",coordinates_factor=1e6,aspect="auto")' % (show_graph_flag, dump_file)
 
     if data_file_flag:
-        full_text_code += "\n\n#" + indent + 'tally.save(filename="%s.h5")' % (root_file_name)
+        full_text_code += "\n\n" + indent + 'tally.save(filename="%s.h5")' % (root_file_name)
 
     full_text_code += "\n\n\n#\n# MAIN========================\n#\n\n"
     full_text_code += "\n\n\nmain()"
